Installation
============

Invenio-Migrator should be installed on both your Invenio legacy installation
and your new Invenio 3 installation.

Invenio Legacy (v1.2/v2.x)
~~~~~~~~~~~~~~~~~~~~~~~~~~
You install Invenio-Migrator on Invenio legacy installations using PyPI:

.. code-block:: console

   $ pip install invenio-migrator


Invenio 3
~~~~~~~~~
You install Invenio-Migrator on Invenio 3 installations using PyPI and the
extra dependencies ``loader``:

.. code-block:: console

   $ pip install invenio-migrator[loader]
